@@ -1,11 +1,15 @@
 
 /**
- * @file tpDep.c
+ * @file agDep.c
  *
  *  This module will load a template and return a template structure.
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  * This file is part of AutoGen.
- * Copyright (c) 1992-2012 Bruce Korb - all rights reserved
+ * Copyright (C) 1992-2015 Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -177,13 +181,13 @@ rm_target_file(char const * pz)
 LOCAL void
 start_dep_file(void)
 {
-
     /*
      * Set dep_file to a temporary file name
      */
     {
         char * tfile_name;
         size_t dep_name_len;
+        int    fd;
 
         if (dep_file == NULL) {
             dep_name_len = strlen(OPT_ARG(BASE_NAME));
@@ -210,14 +214,16 @@ start_dep_file(void)
             q[dep_name_len] = NUL;
         }
 
-        mkstemp(tfile_name);
+        fd = mkstemp(tfile_name);
+        if (fd < 0)
+            AG_CANT(START_DEP_FOPEN_MSG, tfile_name);
         dep_file = tfile_name;
-    }
 
-    /*
-     * Create the file and write the leader.
-     */
-    dep_fp = fopen(dep_file, "w");
+        /*
+         * Create the file and write the leader.
+         */
+        dep_fp = fdopen(fd, "w");
+    }
 
     if (dep_fp == NULL)
         AG_CANT(START_DEP_FOPEN_MSG, dep_file);
@@ -225,7 +231,7 @@ start_dep_file(void)
     fprintf(dep_fp, START_DEP_FILE_FMT, autogenOptions.pzProgPath);
 
     {
-        int     ac = autogenOptions.origArgCt   - 1;
+        int     ac = (int)autogenOptions.origArgCt - 1;
         char ** av = autogenOptions.origArgVect + 1;
 
         for (;;) {
@@ -248,10 +254,14 @@ start_dep_file(void)
             bnm = dep_target;
 
         {
-            size_t sz = strlen(pnm) + strlen(bnm) + 2; // underscore + NUL
+            size_t pnm_sz = strlen(pnm);
+            size_t bnm_sz = strlen(bnm);
 
-            pz_targ_base = pz = AGALOC(sz, "t list");
-            sprintf(pz, DEP_FILE_TARG_FMT, pnm, bnm);
+            pz_targ_base = pz = AGALOC(pnm_sz + bnm_sz + 2, "t list");
+            memcpy(pz, pnm, pnm_sz);
+            pz += pnm_sz;
+            *(pz++) = '_';
+            memcpy(pz, bnm, bnm_sz + 1);
         }
 
         /*
@@ -287,7 +297,7 @@ tidy_dep_file(void)
 
         if (pze == NULL) break;
 
-        len = (pze - dep_file);
+        len = (size_t)(pze - dep_file);
         pzn = AGALOC(len + 1, "dep file");
         memcpy(pzn, dep_file, len);
         pzn[len] = NUL;
@@ -442,3 +452,13 @@ wrap_up_depends(void)
 #endif
     tidy_dep_file();
 }
+
+/**
+ * @}
+ *
+ * Local Variables:
+ * mode: C
+ * c-file-style: "stroustrup"
+ * indent-tabs-mode: nil
+ * End:
+ * end of agen5/agDep.c */
