@@ -73,7 +73,7 @@
 
 #define  LOG10_2to32  10  /* rounded up */
 
-#if defined(SHELL_ENABLED) || defined(DAEMON_ENABLED)
+#if defined(SHELL_ENABLED)
 #  ifndef HAVE_WORKING_FORK
 #    error SHELL is enabled and fork() does not work
      choke me
@@ -401,6 +401,7 @@ MODE char const *   curr_sfx         VALUE( NULL );
  * The time to set for the modification times of the output files.
  */
 MODE time_t         outfile_time     VALUE( 0 );
+MODE time_t         maxfile_time     VALUE( 0 );
 /**
  * The original time autogen started
  */
@@ -468,13 +469,6 @@ MODE def_ctx_t      curr_def_ctx     VALUE( { NULL } );
 MODE def_ctx_t      root_def_ctx     VALUE( { NULL } );
 MODE templ_t *      current_tpl      VALUE( NULL );
 MODE char const *   last_scm_cmd     VALUE( NULL );
-#ifdef DAEMON_ENABLED
-/*
- *  When operating as a daemon, autogen can be told to reload
- *  its options the next time it wakes up (send it a SIGHUP).
- */
-MODE bool           redo_opts        VALUE( true );
-#endif
 
 /*
  *  Current Macro
