@@ -13,9 +13,9 @@
 # define AG_SCM_IS_PROC(_p)           scm_is_true( scm_procedure_p(_p))
 # define AG_SCM_LIST_P(_l)            scm_is_true( scm_list_p(_l))
 # define AG_SCM_PAIR_P(_p)            scm_is_true( scm_pair_p(_p))
-# define AG_SCM_STR02SCM(_s)          scm_from_locale_string(_s)
-# define AG_SCM_STR2SCM(_st,_sz)      scm_from_locale_stringn(_st,_sz)
-# define AG_SCM_TO_NEWSTR(_s)         scm_to_locale_string(_s)
+# define AG_SCM_STR02SCM(_s)          scm_from_latin1_string(_s)
+# define AG_SCM_STR2SCM(_st,_sz)      scm_from_latin1_stringn(_st,_sz)
+# define AG_SCM_TO_NEWSTR(_s)         scm_to_latin1_string(_s)
 # define AG_SCM_STRING_P(_s)          scm_is_string(_s)
 # define AG_SCM_STRLEN(_s)            scm_c_string_length(_s)
 # define AG_SCM_SYM_P(_s)             scm_is_symbol(_s)
