@@ -4,8 +4,12 @@
  *
  *  Parse and process the template data descriptions
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  * This file is part of AutoGen.
- * AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
+ * AutoGen Copyright (C) 1992-2015 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -55,12 +59,12 @@ gen_block(templ_t * tpl, macro_t * mac, macro_t * emac)
         if (fc >= FUNC_CT)
             fc = FTYP_BOGUS;
 
+        scribble_free();
         if (OPT_VALUE_TRACE >= TRACE_EVERYTHING)
             trace_macro(tpl, mac);
 
         cur_macro = mac;
         mac = (*(load_procs[ fc ]))(tpl, mac);
-        ag_scribble_free();
     }
 }
 
@@ -120,7 +124,7 @@ do_stdout_tpl(templ_t * tpl)
         return;
 
     default:
-        fprintf(stdout, DO_STDOUT_TPL_BADR, oops_pfx);
+        fserr(AUTOGEN_EXIT_FS_ERROR, DO_STDOUT_TPL_BADR, oops_pfx);
 
     case FAILURE:
         exit(EXIT_FAILURE);
@@ -155,7 +159,7 @@ do_stdout_tpl(templ_t * tpl)
          *  a content-type: prefix.  If not, we supply our own HTML prefix.
          */
         res   = ag_scm_out_pop(SCM_BOOL_T);
-        pzRes = AG_SCM_CHARS(res);
+        pzRes = scm_i_string_chars(res);
 
         /* 13 char prefix is:  "content-type:" */
         if (strneqvcmp(pzRes, DO_STDOUT_TPL_CONTENT, 13) != 0)
@@ -329,15 +333,15 @@ out_close(bool purge)
      *  Do not deallocate statically allocated names
      */
     if ((cur_fpstack->stk_flags & FPF_STATIC_NM) == 0)
-        AGFREE((void*)cur_fpstack->stk_fname);
+        AGFREE(cur_fpstack->stk_fname);
 
     /*
      *  Do not deallocate the root entry.  It is not allocated!!
      */
     if ((cur_fpstack->stk_flags & FPF_FREE) != 0) {
-        out_stack_t* p = cur_fpstack;
+        out_stack_t * p = cur_fpstack;
         cur_fpstack = p->stk_prev;
-        AGFREE((void*)p);
+        AGFREE(p);
     }
 }
 
@@ -412,9 +416,11 @@ open_output(out_spec_t * spec)
     }
 
     open_output_file(out_file, strlen(out_file), write_mode, 0);
-    free((void *)out_file);
+    free(VOIDP(out_file));
 }
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
