@@ -3,7 +3,7 @@
 ## mklibsrc.sh --   make the libopts tear-off library source tarball
 ##
 ##  This file is part of AutoGen.
-##  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
+##  AutoGen Copyright (C) 1992-2015 by Bruce Korb - all rights reserved
 ##
 ##  AutoGen is free software: you can redistribute it and/or modify it
 ##  under the terms of the GNU General Public License as published by the
@@ -18,8 +18,6 @@
 ##  You should have received a copy of the GNU General Public License along
 ##  with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-set -e
-
 top_builddir=`cd $top_builddir ; pwd`
 top_srcdir=`cd $top_srcdir ; pwd`
 
@@ -39,12 +37,12 @@ tagd=`pwd`/${tag}
 #  WORKING IN SOURCE DIRECTORY
 #
 cd ${top_builddir}/autoopts
-files='libopts.c gettext.h parse-duration.c parse-duration.h '`
+files='libopts.c gettext.h parse-duration.c parse-duration.h
+	stdnoreturn.in.h '$(
     fgrep '#include' libopts.c | \
-       sed -e 's,"$,,;s,#.*",,' \
-           -e '/^compat\/compat\.h$/d' `
+       sed -e 's,"$,,;s,#.*",,' )
 
-for f in ${files}
+for f in ${files} intprops.h
 do
   test -f ${f} &&
     cp -f ${f} ${tagd}/${f} && continue
@@ -60,7 +58,7 @@ cp -f ${top_srcdir}/pkg/libopts/COPYING.* ${tagd}/.
 
 cd ${top_srcdir}/compat
 cp windows-config.h compat.h pathfind.c snprintf.c strdup.c strchr.c \
-   ${tagd}/compat/.
+   ../config/snippet/_Noreturn.h ${tagd}/compat/.
 #
 #  END WORK IN SOURCE DIRECTORY
 #
@@ -68,7 +66,7 @@ cp windows-config.h compat.h pathfind.c snprintf.c strdup.c strchr.c \
 
 cd ${tagd}
 
-cp ${top_srcdir}/config/libopts*.m4 m4/.
+cp ${top_srcdir}/config/libopts*.m4 ${top_srcdir}/config/stdnoret*.m4 m4/.
 chmod u+w m4/libopts.m4
 cat ${top_srcdir}/pkg/libopts/libopts-add.m4 >> m4/libopts.m4
 test ! -f Makefile.am || rm -f Makefile.am
@@ -79,7 +77,7 @@ touch MakeDefs.inc
 
 vers=${AO_CURRENT}:${AO_REVISION}:${AO_AGE}
 {
-  cat <<- EOMakefile
+  sed $'s/^\t//' << EOMakefile
 	## LIBOPTS Makefile
 	MAINTAINERCLEANFILES    = Makefile.in
 	if INSTALL_LIBOPTS
@@ -88,12 +86,23 @@ vers=${AO_CURRENT}:${AO_REVISION}:${AO_AGE}
 	noinst_LTLIBRARIES      = libopts.la
 	endif
 	libopts_la_SOURCES      = libopts.c
-	libopts_la_CPPFLAGS     = -I\$(top_srcdir)
+	libopts_la_CPPFLAGS     = -I\$(srcdir)
 	libopts_la_LDFLAGS      = -version-info ${AM_LDFLAGS} ${vers}
-	EXTRA_DIST              = \\
-	EOMakefile
+	EXTRA_DIST		=
+	BUILT_SOURCES		=
+	MOSTLYCLEANFILES	=
 
+	libopts.c:		\$(BUILT_SOURCES)
+		@: do-nothing rule to avoid default SCCS get
+
+EOMakefile
+
+  printf '\n# Makefile fragment from gnulib-s stdnoreturn module:\n#\n'
+  sed '/^#/d;/^$/d;s/top_srcdir/srcdir/' \
+    ${top_srcdir}/pkg/libopts/stdnoreturn.mk
+  printf '\nEXTRA_DIST += \\\n'
   find $(ls -A) -type f \
+    | env LC_COLLATE=C sort \
     | egrep -v '^(libopts\.c|Makefile\.am)$' \
     | ${CLexe} -I4 --spread=1 --line-sep="  \\"
 } > Makefile.am
